# 
# The following is stolen from ctsql-1.4 and modified by:
#    Copyright (C) 1995, 1996  Steve Etchelecu
# Modifications:
#    Copyright (C) 1996  Scott C. Gray
# Additional modifications:
#    Copyright (C) 2001  Michael Peppler
# 
# Permission to use, copy, modify, distribute, and sell this software
# and its documentation for any purpose is hereby granted without fee,
# provided that (i) the above copyright notices and this permission
# notice appear in all copies of the software and related documentation,
# and (ii) the name of Steve Etchelecu may not be used in any
# advertising or publicity relating to the software without the
# specific, prior written permission of Steve Etchelecu.
# 
# THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND,
# EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY
# WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
# 
# IN NO EVENT SHALL STEVE ETCHELECU BE LIABLE FOR ANY SPECIAL,
# INCIDENTAL, INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY
# DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
# WHETHER OR NOT ADVISED OF THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY
# OF LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
# PERFORMANCE OF THIS SOFTWARE.
# 
#   Author: Steve Etchelecu              	 DBA
# Internet: steve.etchelecu@sunquest.com 	 Sunquest Information Systems
#    Phone: (520)733-6363                	 4801 E. Broadway Blvd.
#      FAX: (520)733-6602                       Tucson, AZ 85711

AC_DEFUN(AC_SYBASE_INSTALLATION, [

#
#  Is $SYBASE defined?
#
AC_MSG_CHECKING(Open Client installation)

	if test "$SYBASE" != "" ; then
		AC_MSG_RESULT($SYBASE)
	else
		AC_MSG_RESULT(no)
		AC_MSG_ERROR([Unable to locate Sybase installation
			Check your SYBASE environment variable setting.])
	fi

	if test "$SYBASE_OCS" != "" ; then
		SYBASE_DIR="$SYBASE/$SYBASE_OCS"
	else
		SYBASE_DIR=$SYBASE
	fi

	if test -d $SYBASE_DIR/include ; then
		SYBASE_INCDIR='-I$(SYBASE_DIR)/include'
	else
		AC_MSG_ERROR([Sybase include files not found in \$SYBASE
			Check your SYBASE environment variable setting.])
	fi

#
# What is the version of Open Client?
#
AC_MSG_CHECKING(Open Client version)

	SYBASE_VERSION=`strings $SYBASE_DIR/lib/libct.a 2>/dev/null | \
		cut -c1-80 | fgrep 'Sybase Client-Library' | cut -d '/' -f 2`
	AC_MSG_RESULT($SYBASE_VERSION)

AC_MSG_CHECKING(Open Client libraries)

	if test ! -d $SYBASE_DIR/lib ; then
		AC_MSG_ERROR([Sybase libraries not found in \$SYBASE
			Check your SYBASE environment variable setting.])
	fi

	if test "$with_devlib" = "yes"
	then
		SYBASE_LIBDIR='-L$(SYBASE_DIR)/devlib'
	else
		SYBASE_LIBDIR='-L$(SYBASE_DIR)/lib'
	fi

	#
	# The basic client libraries that are always needed
	# on all platforms.
	#
	SYBASE_LIBS="-lblk -lcs -lct -lcomn -ltcl -lintl"

	MAJOR_VERSION=`echo $SYBASE_VERSION | cut -d '.' -f 1`

	#
	# For versions prior to 10.0.x, the network drivers must
	# be linked in with the actual binary.
	#
	if test "$MAJOR_VERSION" -lt 11
	then
		if test -f $SYBASE_DIR/lib/libinsck.a -o  \
		        -f $SYBASE_DIR/lib/libinsck.so -o \
		        -f $SYBASE_DIR/lib/libinsck.sl
		then
			SYBASE_LIBS="$SYBASE_LIBS -linsck"
		else
			if test -f $SYBASE_DIR/lib/libtli.a -o  \
			        -f $SYBASE_DIR/lib/libtli.so -o \
			        -f $SYBASE_DIR/lib/libtli.sl
			then
				SYBASE_LIBS="$SYBASE_LIBS -ltli"
			fi
		fi
	fi

	case "${host_os}" in
		linux*)
			SYBASE_LIBS=`echo $SYBASE_LIBS | \
				sed -e 's,-ltcl,-lsybtcl,g'`
	esac


	AC_MSG_RESULT($SYBASE_LIBS)

AC_MSG_CHECKING(Open Client OS libraries)

	case "${host_os}" in
		linux*)
			SYBASE_OS="-ldl -lm";;
		irix*)
			SYBASE_OS="-lnsl -lm";;
		ncr*)
			SYBASE_OS="-ldl -lm";;
		sunos*)
			SYBASE_OS="-lm";;
		solaris*)
			SYBASE_OS="-lnsl -ldl -lm";;
		osf1*)
			SYBASE_OS="-lsdna -ldnet_stub -lm";;
		ultrix*)
			SYBASE_OS="-lsdna -ldnet_stub -lm";;
		hpux*)
			SYBASE_OS="-lcl -lm -lsec -lBSD";;
		dgux*)
			SYBASE_OS="-lm -ldl -ldgc";;
		aix*)
			SYBASE_OS="-lm";;
		*)
			SYBASE_OS="-lm -ldl";;
	esac

	AC_MSG_RESULT($SYBASE_OS)


#	if test "$with_static" = "yes"
#	then
#		SYBASE_LIBS=`echo $SYBASE_LIBS | \
#			sed -e 's,-l\([[a-z]]*\),\$(SYBASE)/lib/lib\1.a,g'`
#	fi

	AC_SUBST(SYBASE)
	AC_SUBST(SYBASE_DIR)
	AC_SUBST(SYBASE_INCDIR)
	AC_SUBST(SYBASE_LIBDIR)
	AC_SUBST(SYBASE_LIBS)
	AC_SUBST(SYBASE_OS)

])
