/* 
 * $Id: bcptool.h,v 1.2 2001/01/17 19:43:29 mpeppler Exp $
 *
 * bcptool.h
 *
 * Copyright (C) 2001 by Michael Peppler
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, write to the Free Software
 * Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * You may contact the author :
 *   e-mail:  mpeppler@peppler.org
 *
 */

#if !defined(bcptool_h_included)
#define bcptool_h_included = 1

#include "config.h"

#if defined(HAVE_ERRNO_H)
#include <errno.h>
#endif

extern int errno;

#if !defined(HAVE_VOLATILE)
#  define volatile
#endif

#if defined(HAVE_STRING_H)
#include <string.h>
#endif

#if defined(HAVE_STRINGS_H)
#include <strings.h>
#endif

#if defined(HAVE_UNISTD_H)
#include <unistd.h>
#endif

#if defined(HAVE_STDLIB_H)
#include <stdlib.h>
#endif

#if defined(HAVE_SYS_TYPES_H)
#include <sys/types.h>
#endif

#if defined(HAVE_SYS_WAIT_H)
#include <sys/wait.h>
#endif

#if defined(HAVE_FCNTL_H)
#include <fcntl.h>
#endif

#if defined(HAVE_MEMORY_H)
#include <memory.h>
#endif

#if defined(HAVE_TIME_H)
#include <time.h>
#endif

#if defined(HAVE_SYS_TIME_H)
#include <sys/time.h>
#endif

#if defined(HAVE_LIMITS_H)
#include <limits.h>
#endif


#include <stdio.h>

#include "dbutil.h"

#define DBOPT_BCP 	(1 << 0)
#define DBOPT_TRUNC	(1 << 1)
#define DBOPT_IDENTITY  (1 << 2)

/*
 * bcp_col_t: This data structure represents a single column of data
 *            as it returns from the server.  Note that all data is
 *            fetched and sent in its native data type.
 */
typedef struct _bcp_col_t {
    CS_INT      c_colid;       /* Column number */
    CS_DATAFMT  c_format;      /* Format for column */
    CS_INT      c_len;         /* Length of current row */
    CS_INT      c_prevlen;     /* Length of previous row */
    CS_SMALLINT c_nullind;     /* Null indicator for current row */
    CS_SMALLINT c_prevnullind; /* Null indicator for previous row */
    CS_VOID    *c_data;        /* Data space for fetch and bind */
} bcp_col_t;

/*
 * bcp_data_t: Represents an entire row of data.
 */
typedef struct _bcp_data_t {
    CS_INT      d_type;        /* Result type */
    CS_INT      d_ncols;       /* Number of columns to fetch */
    CS_BOOL     d_bound;       /* Have we bound */
    bcp_col_t  *d_cols;        /* Array of columns */
} bcp_data_t;


typedef struct columns {
    char name[34];
    int  type;
    char type_name[34];
    int  length;
    int  precision;
    int  scale;
    int  nullable;
    int  identity;
    int  selected;
} COLUMN;

typedef struct tables {
    char name[34];
    char *dbname;
    int  numCols;
    int  numSelectedCols;
    int  rows;

    int  rowcount;
    int  batchsize;
    int  selected;
    int  trunc_target;
    int  id_insert;

    int  target_has_identity;	/* true if target table has identity column */
    int  target_id_col;		/* identity column # of target */
    int  target_id_precision;
    bcp_col_t *id_col;		/* used for binding 0 value identity col */

    char where_clause[1024];
    char target_table[64];
    char target_db[64];
    
    int tiindex;
    int maxindex;
    int pages;
    int tipages;
    
    COLUMN ** cols;
} TABLE;

typedef struct database {
    char name[34];
    int num_tables;
    int selected;
    unsigned int options;

    TABLE ** tables;
} DB;


GtkWidget *window1;
GtkWidget *window2;
GtkWidget *window3;
GtkWidget *window4;
GtkWidget *dialog1;
GtkWidget *dialog2;

//#define DEBUG

#endif;
