/*
 * $Id: dbutil.h,v 1.2 2001/01/17 19:43:48 mpeppler Exp $
 *
 * dbutil.h     - Simple DB access using CT-lib
 *
 * Copyright (C) 2001 by Michael Peppler
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, write to the Free Software
 * Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * You may contact the author :
 *   e-mail:  mpeppler@peppler.org
 *
 */

#include <ctpublic.h>

#if !defined(dbutil_h_included)
#define dbutil_h_included

#if defined(CS_VERSION_125)
#define CTLIB_VERSION   CS_VERSION_125
#else 
#if defined(CS_VERSION_120)
#define CTLIB_VERSION   CS_VERSION_120
#else 
#if defined(CS_VERSION_110)
#define CTLIB_VERSION   CS_VERSION_110
#else
#define CTLIB_VERSION	CS_VERSION_100
#endif
#endif
#endif


typedef struct _col_data
{
    CS_SMALLINT	indicator;
    CS_INT	type;
    CS_INT      realType;
    CS_INT      realLength;
    union {
	CS_CHAR	*c;
	CS_INT i;
	CS_FLOAT f;
/*	CS_DATETIME dt;
	CS_MONEY mn;
	CS_NUMERIC num; */
    } value;
    CS_INT	valuelen;
} ColData;

typedef struct dbh {
    CS_CONTEXT    *context;
    CS_CONNECTION *connection;
    CS_LOCALE     *locale;
    CS_COMMAND    *cmd;
    CS_DATAFMT    *datafmt;
    ColData       *coldata;

    int           debug;

    int           numCols;
    CS_INT        lastResType;
    int           isDead;
    int           done_desc;
    
    char server[64];
    char userName[64];
    char password[64];
} DBH;


/* NOTE: proc return status is not included in the ROW list - it's kept 
   in the RESULTS struct */
typedef struct row {
    struct row *next;
    int     resNum;
    int     rowNum;
    int     numCols;
    ColData *data;
} ROW;

typedef struct resultList {
    int resNum;
    int numCols;
    ROW *row;

    ROW *last;			// speed optimization
    
    struct resultList *next;
} RESULT_LIST;

typedef struct results {
    int    procStatus;
    int    numResults;
    int    lastError;
    int    hasProcStatus;
    
    RESULT_LIST *result;	// first result set

    RESULT_LIST *current;	// the one currently being processed - used
				// internally.
} RESULT;    

/* prototypes */

void db_init(void);
DBH *db_connect ( char *server, char *user, char *pwd, char *packetsize,
		  int encryption, char *charset, int bcp );
RESULT *db_exec_sql(DBH *dbh, char *sql);
void db_dump(RESULT *retdata);
void db_free_result(RESULT *retdata);
void db_set_errfunc(void (*func)());
void db_set_msgfunc(void (*func)());
void db_use (DBH *dbh, char *database);
void db_free (DBH *dbh);


#endif    /* dbutil_h_included */
